Package: animalcules
Title: Interactive microbiome analysis toolkit
Version: 1.28.0
Authors@R: c(person(given=c("W.", "Evan"), family="Johnson", email="wej@bu.edu",
                role=c("aut", "cre"),
                comment = c(ORCID = "0000-0002-6247-6595")),
            person(given="Yue", family="Zhao", email="yuezh@bu.edu",
                role=c("aut"), comment = c(ORCID = "0000-0001-5257-5103")),
            person(given="Anthony", family="Federico", email="anfed@bu.edu",
                role=c("aut"), comment = c(ORCID = "0000-0002-9200-1689")),
            person(given="Jessica", family="Anderson",
                email="anderson.jessica@rutgers.edu", role=c("ctr"),
                comment = c(ORCID = "0000-0002-0542-9872")))
Description: 
    animalcules is an R package for utilizing up-to-date data analytics,
    visualization methods, and machine learning models to provide users
    an easy-to-use interactive microbiome analysis framework. It can be
    used as a standalone software package or users can explore their data
    with the accompanying interactive R Shiny application. Traditional
    microbiome analysis such as alpha/beta diversity and differential
    abundance analysis are enhanced, while new methods like biomarker
    identification are introduced by animalcules. Powerful interactive
    and dynamic figures generated by animalcules enable users to
    understand their data better and discover new insights.
License: Artistic-2.0
URL: https://github.com/wejlab/animalcules
BugReports: https://github.com/wejlab/animalcules/issues
Depends: R (>= 4.3.0)
Imports: ape, assertthat, caret, covr, DESeq2, dplyr, DT, forcats,
        ggforce, ggplot2, GUniFrac, lattice, limma, magrittr, Matrix,
        methods, MultiAssayExperiment, plotly, rentrez, reshape2,
        ROCit, S4Vectors (>= 0.23.19), scales, shiny, shinyjs, stats,
        SummarizedExperiment, tibble, tidyr, tsne, umap, utils, vegan,
        XML
Suggests: BiocStyle, biomformat, devtools, glmnet, knitr, rmarkdown,
        testthat, usethis
VignetteBuilder: knitr
biocViews: Microbiome, Metagenomics, Coverage, Visualization
Encoding: UTF-8
RoxygenNote: 7.3.0
git_url: https://git.bioconductor.org/packages/animalcules
git_branch: RELEASE_3_23
git_last_commit: eb03d7e
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:22:59 UTC; biocbuild
Author: W. Evan Johnson [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6247-6595>),
  Yue Zhao [aut] (ORCID: <https://orcid.org/0000-0001-5257-5103>),
  Anthony Federico [aut] (ORCID: <https://orcid.org/0000-0002-9200-1689>),
  Jessica Anderson [ctr] (ORCID: <https://orcid.org/0000-0002-0542-9872>)
Maintainer: W. Evan Johnson <wej@bu.edu>
Built: R 4.6.0; ; 2026-04-29 04:33:03 UTC; unix
