# Generated by roxygen2: do not edit by hand

export(alpha_div_boxplot)
export(alpha_div_test)
export(counts_to_logcpm)
export(counts_to_relabu)
export(df_char_to_factor)
export(differential_abundance)
export(dimred_pca)
export(dimred_pcoa)
export(dimred_tsne)
export(dimred_umap)
export(diversities)
export(diversities_help)
export(diversity_beta_NMDS)
export(diversity_beta_boxplot)
export(diversity_beta_heatmap)
export(diversity_beta_test)
export(do_alpha_div_test)
export(filter_categorize)
export(filter_summary_bar_density)
export(filter_summary_pie_box)
export(find_biomarker)
export(find_taxon_mat)
export(find_taxonomy)
export(find_taxonomy_300)
export(gini_simpson)
export(grep_tid)
export(inverse_simpson)
export(is_categorical)
export(is_integer0)
export(is_integer1)
export(mae_pick_organisms)
export(mae_pick_samples)
export(pct2str)
export(percent)
export(read_pathoscope_data)
export(relabu_barplot)
export(relabu_boxplot)
export(relabu_heatmap)
export(run_animalcules)
export(shannon)
export(simpson_index)
export(upsample_counts)
export(write_to_biom)
import(DESeq2)
import(DT)
import(GUniFrac)
import(MultiAssayExperiment)
import(SummarizedExperiment)
import(XML)
import(ape, except = where)
import(ape, except = where)

import(assertthat)
import(covr)
import(dplyr)
import(ggforce)
import(ggplot2, except = last_plot)
import(lattice)
import(magrittr)
import(plotly)
import(rentrez)
import(reshape2)
import(scales)
import(tibble, except = has_name)
import(tidyr, except = extract)
import(tsne)
import(umap)
import(vegan)
importFrom(Matrix,Matrix)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,topTable)
importFrom(magrittr,"%>%")
importFrom(methods,as)
importFrom(shinyjs,addClass)
importFrom(stats,as.formula)
importFrom(stats,cor.test)
importFrom(stats,density)
importFrom(stats,kruskal.test)
importFrom(stats,model.matrix)
importFrom(stats,quantile)
importFrom(stats,t.test)
importFrom(stats,wilcox.test)
importFrom(utils,read.table)
